@@ -21,20 +21,20 @@ import os
 import datetime as dt
 
 def simple(facts, start_date, end_date):
+    dates_dict = stuff.dateDict(start_date, "start_")
+    dates_dict.update(stuff.dateDict(end_date, "end_"))
+    
+    
     if start_date.year != end_date.year:
-        start_str = start_date.strftime('%B %d. %Y')
-        end_str = end_date.strftime('%B %d. %Y')
+        title = _("Overview for %(start_B)s %(start_d)s, %(start_Y)s – %(end_B)s %(end_d)s, %(end_Y)s") % dates_dict
     elif start_date.month != end_date.month:
-        start_str = start_date.strftime('%B %d')
-        end_str = end_date.strftime('%B %d')
+        title = _("Overview for %(start_B)s %(start_d)s – %(end_B)s %(end_d)s, %(end_Y)s") % dates_dict
     else:
-        start_str = start_date.strftime('%B %d')
-        end_str = end_date.strftime('%d, %Y')
+        title = _("Overview for %(start_B)s %(start_d)s – %(end_d)s, %(end_Y)s") % dates_dict
 
     if start_date == end_date:
-        title = _("Overview for %s") % (start_date.strftime('%B %d. %Y'))
-    else:
-        title = _("Overview for %s - %s") % (start_str, end_str)
+        title = _("Overview for %(start_B)s %(start_d)s, %(start_Y)s") % dates_dict
+    
 
     report_path = os.path.join(os.path.expanduser("~"), "%s.html" % title)
     report = open(report_path, "w")    
@@ -73,12 +73,12 @@ def simple(facts, start_date, end_date):
     
     report.write("""<table>
         <tr>
-            <th>Date</th>
-            <th>Activity</th>
-            <th>Category</th>
-            <th>Start</th>
-            <th>End</th>
-            <th>Duration</th>
+            <th>""" + _("Date") + """</th>
+            <th>""" + _("Activity") + """</th>
+            <th>""" + _("Category") + """</th>
+            <th>""" + _("Start") + """</th>
+            <th>""" + _("End") + """</th>
+            <th>""" + _("Duration") + """</th>
         </tr>""")
     
     
@@ -100,7 +100,7 @@ def simple(facts, start_date, end_date):
         category = ""
         if fact["category"] != _("Unsorted"): #do not print "unsorted"
             category = fact["category"]
-
+        # fact date column in HTML report
         report.write("""<tr>
                             <td>%s</td>
                             <td>%s</td>
@@ -108,7 +108,7 @@ def simple(facts, start_date, end_date):
                             <td>%s</td>
                             <td>%s</td>
                             <td>%s</td>
-</tr>""" % (fact["start_time"].strftime("%d.%m.%y"),
+</tr>""" % (_("%(report_b)s %(report_d)s, %(report_Y)s") % stuff.dateDict(fact["start_time"], "report_"),
             fact["name"],
             category, 
             fact["start_time"].strftime('%H:%M'),
